using System;
using System.Drawing;
using System.Drawing.Drawing2D;
using System.Windows.Forms;
using System.Collections;

namespace DrawingObjects
{
	public class Scene {
		private Pen selectionPen;
		private ArrayList glyphs;
		private Control control;

		public Scene(Control control) {
			this.control = control;
			glyphs = new ArrayList();
			selectionPen = new Pen(Color.Black, 0);
			selectionPen.DashStyle = DashStyle.Dot;
		}

		public void AddGlyph(Glyph glyph) {
			glyphs.Add(glyph);
			Repaint();
		}

		// Schedule a request to repaint the scene later
		public void Repaint() {
			control.Invalidate();
		}

		// Paint the scene immediately
		public void Paint(Graphics g) {
			// Paint background
			g.Clear(Color.White);

			// Paint glyphs
			foreach (Glyph glyph in glyphs) {
				glyph.Paint(g);
			}
		}

		// Returns the first glyph that contains this point in global coordinates (in top to bottom order)
		public Glyph Pick(int x, int y) {
			Glyph hit = null;
			Glyph glyph;
			for (int i=glyphs.Count-1; i>=0; i--) {
				glyph = (Glyph)glyphs[i];
				if (glyph.Contains(x, y)) {
					hit = glyph;
					break;
				}
			}

			return hit;
		}

		public void UnselectAll() {
			foreach (Glyph g in glyphs) {
				if (g.Selected) {
					g.Selected = false;
				}
			}
		}

		/*********************************
		 * Internal Implementation
		 ********************************/
		internal Pen SelectionPen {
			get { return selectionPen; }
		}
	}
}