using System;
using System.Drawing;
using System.Drawing.Drawing2D;
using System.Collections;
using System.ComponentModel;
using System.Windows.Forms;
using System.Data;

/*
 * A simple architecture for drawing objects.
 * It keeps a list of "Glyphs" that can be added to a scene.
 * Each glyph supports a transformation matrix and selection,
 * and the scene keeps track of redrawing the glyphs.
 * 
 * (C) Ben Bederson, University of Maryland
 * April, 2005
 */
namespace DrawingObjects {
	public class Tester : System.Windows.Forms.Form {
		public enum Mode {Selection};
		private System.ComponentModel.Container components = null;

		protected Scene scene;
		protected Mode mode = Mode.Selection;
		protected bool shiftDown;

		public Tester() {
			InitializeComponent();

			// Create a scene and add some event handlers
			scene = new Scene(this);

			KeyDown += new KeyEventHandler(Tester_KeyDown);
			KeyUp += new KeyEventHandler(Tester_KeyUp);
			MouseDown += new MouseEventHandler(Tester_MouseDown);

			// Create a few rectangles
			RectGlyph rg;
			rg = new RectGlyph(scene, 10, 10, 50, 50);
			scene.AddGlyph(rg);

			EllipseGlyph eg;
			eg = new EllipseGlyph(scene, 50, 50, 80, 80);
			eg.Pen = new Pen(Color.Blue);
			eg.Brush = new SolidBrush(Color.LightBlue);
			scene.AddGlyph(eg);

			rg = new RectGlyph(scene, 100, 0, 40, 40);
			rg.Pen = null;
			rg.Brush = new LinearGradientBrush(new Point(100, 0), new Point(140, 40), Color.Yellow, Color.Red);
			Matrix m = new Matrix();
			m.Rotate(15.0f);
			rg.Transform = m;
			scene.AddGlyph(rg);
		}

		protected override void OnPaint(PaintEventArgs e) {
			scene.Paint(e.Graphics);
		}

		protected override void Dispose( bool disposing ) {
			if( disposing ) {
				if (components != null) {
					components.Dispose();
				}
			}
			base.Dispose( disposing );
		}

		#region Windows Form Designer generated code
		/// <summary>
		/// Required method for Designer support - do not modify
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent() {
			// 
			// Tester
			// 
			this.AutoScaleBaseSize = new System.Drawing.Size(5, 13);
			this.ClientSize = new System.Drawing.Size(292, 266);
			this.Name = "Tester";
			this.Text = "DrawingObjects Tester";

		}
		#endregion

		[STAThread]
		static void Main() {
			Application.Run(new Tester());
		}

		private void Tester_MouseDown(object sender, MouseEventArgs e) {
			Glyph glyph = scene.Pick(e.X, e.Y);

			if (glyph == null) {
				scene.UnselectAll();
			} else {
				if (shiftDown) { // shift
					glyph.Selected = !glyph.Selected;
				} else {
					if (!glyph.Selected) {
						scene.UnselectAll();
						glyph.Selected = true;
					}
				}
			}
		}

		private void Tester_KeyDown(object sender, KeyEventArgs e) {
			shiftDown = e.Shift;
		}

		private void Tester_KeyUp(object sender, KeyEventArgs e) {
			shiftDown = e.Shift;
		}
	}
}